@@ -28,6 +28,8 @@ from dbt_cloud.field import PythonLiteralOption
 
 def execute_and_print(command, **kwargs):
     response = command.execute(**kwargs)
+    print(response)
+    print(response.content)
     click.echo(dict_to_json(response.json()))
     response.raise_for_status()
     return response
@@ -345,6 +347,7 @@ def query(file, **kwargs):
     command = DbtCloudMetadataQueryCommand.from_click_options(
         query=file.read(), **kwargs
     )
+    print(command.query)
     execute_and_print(command)
 
 
