@@ -2,7 +2,7 @@ import requests
 from enum import IntEnum
 from typing import Optional, List
 from pydantic import Field
-from dbt_cloud.command.command import DbtCloudCommand
+from dbt_cloud.command.command import DbtCloudAccountCommand
 from dbt_cloud.field import RUN_ID_FIELD
 
 
@@ -15,7 +15,7 @@ class DbtCloudRunStatus(IntEnum):
     CANCELLED = 30
 
 
-class DbtCloudRunGetCommand(DbtCloudCommand):
+class DbtCloudRunGetCommand(DbtCloudAccountCommand):
     """Returns the details of a dbt Cloud run."""
 
     run_id: int = RUN_ID_FIELD
